@@ -15,7 +15,11 @@
 
 
 from spacy_syllables import SpacySyllables
+from stylo_metrix.pipeline.en.pos_tagger import POSTagger
+from stylo_metrix.pipeline.en.metrics import Metrics
 
-COMPONENTS_EN = [
+COMPONENTS = [
     SpacySyllables,
+    POSTagger,
+    Metrics,
 ]
