@@ -22,7 +22,7 @@ from stylo_metrix.pipeline.pl.pos_tagger import POSTagger
 from stylo_metrix.pipeline.pl.psycholinguistic import Psycholinguistic
 from stylo_metrix.pipeline.pl.sentence_segmenter import SentenceSegmenter
 
-COMPONENTS_PL = [
+COMPONENTS = [
     SpacySyllables,
     SentenceSegmenter,
     POSTagger,
