@@ -15,24 +15,37 @@
 
 
 from spacy.language import Language
+from spacy.tokens import Doc
 
-from stylo_metrix.pipeline.en import COMPONENTS_EN
-from stylo_metrix.pipeline.pl import COMPONENTS_PL
+from stylo_metrix.structures.errors import LanguageNotImplemented
 
 
 @Language.factory("stylo_metrix")
 class StyloMetrixPipe():
+    name_count = 0
 
     def __init__(self, nlp, name):
         lang = nlp.config["nlp"]["lang"]
+
         if lang == "pl":
-            self.components = [component(nlp) for component in COMPONENTS_PL]
+            from stylo_metrix.pipeline.pl import COMPONENTS
         elif lang == "en":
-            self.components = [component(nlp) for component in COMPONENTS_EN]
+            from stylo_metrix.pipeline.en import COMPONENTS
         else:
-            print(f"The language code [{lang}] is not supported by StyloMetrix.")
+            raise LanguageNotImplemented()
+
+        self.components = [component(nlp) for component in COMPONENTS]
+        Doc.set_extension("name", default=None, force=True)
+        Doc.set_extension("assign_name", method=self.assign_name, force=True)
 
     def __call__(self, doc):
         for component in self.components:
             doc = component(doc)
+
+        doc._.set("name", f"SM{StyloMetrixPipe.name_count:06d}")
+        StyloMetrixPipe.name_count += 1
+        return doc
+
+    def assign_name(self, doc, name):
+        doc._.name = name
         return doc
